import type { TextureSet } from './AestheticSet';
import { Vector } from 'apache-arrow';
import { StructRowProxy } from 'apache-arrow/row/struct';
import type * as DS from '../shared';
import { Scatterplot } from '../scatterplot';
/**
 * An Aesthetic bundles all operations in mapping from user dataspace to webGL based aesthetics.
 *
 * It is a generic type that needs to be subclassed. The GLType represents the convention that we
 * use on the GPU for representing it: in every case except for colors, data is represented as an
 * indeterminate precision float. Colors are represented as a three-tuple.
 *
 * The JSValue type represents how the user expects to interact with these in the setting of
 * ranges. Again, these are generally numbers, but they can be strings for special instructions,
 * especially for colors.
 */
export declare abstract class Aesthetic<ChannelType extends DS.ChannelType, Input extends DS.InType = DS.NumberIn, Output extends DS.OutType = DS.NumberOut> {
    abstract default_constant: Output['rangeType'];
    abstract default_range: [Output['rangeType'], Output['rangeType']];
    scatterplot: Scatterplot;
    field: string | null;
    _texture_buffer: Float32Array | Uint8Array | null;
    protected abstract _func?: (d: Input['domainType']) => Output['rangeType'];
    aesthetic_map: TextureSet;
    column: Vector<Input['arrowType']> | null;
    encoding: ChannelType;
    id: string;
    constructor(encoding: ChannelType | null, scatterplot: Scatterplot, aesthetic_map: TextureSet, id: string);
    get dataset(): DS.Dataset;
    abstract apply(point: Datum): Output['rangeType'];
    abstract toGLType(val: Output['rangeType']): Output['glType'];
    get webGLDomain(): [number, number];
    default_data(): Uint8Array | Float32Array | Array<number>;
    value_for(point: Datum): Input['domainType'] | null;
    get map_position(): number;
    get texture_buffer(): Uint8Array;
    post_to_regl_buffer(): void;
    arrow_column(): Vector<Input['arrowType']> | null;
    is_dictionary(): boolean;
    /**
     * Returns the default value
     */
    get webGLconstant(): Output['glType'];
    get use_map_on_regl(): 1 | 0;
}
export type Datum = StructRowProxy | Record<string, string | number | boolean>;
//# sourceMappingURL=Aesthetic.d.ts.map