import type { Regl, Texture2D } from 'regl';
import { dimensions } from './StatefulAesthetic';
import type { Scatterplot } from '../scatterplot';
import type { Dataset } from '../Dataset';
import { StatefulAesthetic } from './StatefulAesthetic';
import type { Encoding } from '../shared';
import type * as DS from '../shared';
type AesMap = {
    [K in keyof typeof dimensions]: StatefulAesthetic<InstanceType<(typeof dimensions)[K]>>;
};
type StateList<T> = {
    current: T;
    last: T;
};
export declare class AestheticSet {
    tileSet: Dataset;
    scatterplot: Scatterplot;
    regl: Regl;
    encoding: Encoding;
    position_interpolation: boolean;
    readonly store: AesMap;
    aesthetic_map: TextureSet;
    options: {
        jitter_method: StateList<DS.JitterMethod>;
    };
    constructor(scatterplot: Scatterplot, regl: Regl, tileSet: Dataset);
    dim(aesthetic: keyof typeof dimensions): StatefulAesthetic<DS.ConcreteAesthetic>;
    [Symbol.iterator](): Generator<number>;
    interpret_position(encoding: Encoding): void;
    apply_encoding(encoding: Encoding): void;
    jitter_int_format(time: 'last' | 'current'): 0 | 1 | 2 | 3 | 4 | 5;
}
export declare class TextureSet {
    /**
     * A texture set manages memory allocation for scales. It's mostly
    used for handling color aesthetics (through the set_color function)
  
     */
    private _one_d_texture?;
    private _color_texture?;
    texture_size: number;
    regl: Regl;
    id_locs: Record<string, number>;
    texture_widths: number;
    private offsets;
    private _one_d_position;
    private _color_position;
    constructor(regl: Regl, texture_size?: number);
    get_position(id: string): number;
    set_one_d(id: string, value: number[] | Uint8Array | Float32Array): void;
    set_color(id: string, value: Uint8Array): void;
    get one_d_texture(): Texture2D;
    get color_texture(): Texture2D;
}
export {};
//# sourceMappingURL=AestheticSet.d.ts.map