import type * as DS from '../shared';
import { Aesthetic, Datum } from './Aesthetic';
import { Scatterplot } from '../scatterplot';
import type { TextureSet } from './AestheticSet';
import { scaleLinear, scaleSqrt, scaleLog, scaleIdentity, ScaleContinuousNumeric, ScaleOrdinal } from 'd3-scale';
export declare const scales: {
    readonly sqrt: typeof scaleSqrt;
    readonly log: typeof scaleLog;
    readonly linear: typeof scaleLinear;
    readonly literal: typeof scaleIdentity;
};
export declare abstract class ScaledAesthetic<ChannelType extends DS.ChannelType = DS.ChannelType, Input extends DS.NumberIn | DS.DateIn | DS.CategoryIn = DS.NumberIn | DS.DateIn | DS.CategoryIn, Output extends DS.NumberOut | DS.ColorOut = DS.NumberOut | DS.ColorOut> extends Aesthetic<ChannelType, Input, Output> {
    protected _scale: ScaleContinuousNumeric<Input['domainType'], Output['rangeType']> | ScaleOrdinal<Input['domainType'], Output['rangeType']>;
    default_transform: DS.Transform;
    abstract default_range: [Output['rangeType'], Output['rangeType']];
    protected categorical: any;
    constructor(encoding: ChannelType | null, scatterplot: Scatterplot, aesthetic_map: TextureSet, id: string);
    protected categoricalRange(): Output['rangeType'][];
    protected categoricalValues(): Input['domainType'][];
    protected populateCategoricalScale(): void;
    private _webGLDomain;
    /**
     * Returns two numbers that indicate the extent of
     * the attribute written to webGL.
     */
    get webGLDomain(): [number, number];
    get transform(): DS.Transform;
    get scale(): ScaleContinuousNumeric<Input["domainType"], Output["rangeType"], never> | ScaleOrdinal<Input["domainType"], Output["rangeType"], never>;
    apply(point: Datum): Output["rangeType"];
    get default_domain(): [number, number];
    get categoricalDomain(): Input['domainType'][];
    get domain(): [Input['domainType'], Input['domainType']];
    get range(): [Output['rangeType'], Output['rangeType']];
}
declare abstract class OneDAesthetic<ChannelType extends DS.OneDChannels = DS.OneDChannels, Input extends DS.NumberIn | DS.DateIn | DS.CategoryIn = DS.NumberIn> extends ScaledAesthetic<ChannelType, Input, DS.NumberOut> {
    constructor(encoding: ChannelType | null, scatterplot: Scatterplot, aesthetic_map: TextureSet, id: string);
    protected _func?: (d: Input['domainType']) => number;
    toGLType(a: number): number;
    get default_domain(): [number, number];
}
export declare class Size<ChannelType extends DS.OneDChannels = DS.OneDChannels, Input extends DS.NumberIn | DS.DateIn | DS.CategoryIn = DS.NumberIn | DS.DateIn | DS.CategoryIn> extends OneDAesthetic<ChannelType, Input> {
    default_constant: number;
    get default_range(): [number, number];
    default_transform: DS.Transform;
}
export declare abstract class PositionalAesthetic<ChannelType extends DS.OneDChannels = DS.OneDChannels, Input extends DS.NumberIn | DS.DateIn | DS.CategoryIn = DS.NumberIn | DS.DateIn | DS.CategoryIn> extends OneDAesthetic<ChannelType, Input> {
    default_constant: number;
    default_transform: DS.Transform;
    abstract axis: 'x' | 'y';
    get range(): [number, number];
    get default_range(): [number, number];
}
export declare class X<ChannelType extends DS.OneDChannels = DS.OneDChannels, Input extends DS.NumberIn | DS.DateIn | DS.CategoryIn = DS.NumberIn | DS.DateIn | DS.CategoryIn> extends PositionalAesthetic<ChannelType, Input> {
    axis: "x";
}
export declare class Y<ChannelType extends DS.OneDChannels = DS.OneDChannels, Input extends DS.NumberIn | DS.DateIn | DS.CategoryIn = DS.NumberIn | DS.DateIn | DS.CategoryIn> extends PositionalAesthetic<ChannelType, Input> {
    axis: "y";
}
export declare class Jitter_speed<ChannelType extends DS.OneDChannels = DS.OneDChannels, Input extends DS.NumberIn | DS.DateIn | DS.CategoryIn = DS.NumberIn> extends OneDAesthetic<ChannelType, Input> {
    default_transform: DS.Transform;
    get default_range(): [number, number];
    default_constant: number;
    _constant: number;
}
export declare class Jitter_radius extends OneDAesthetic {
    _constant: number;
    toGLType(a: number): number;
    get default_constant(): number;
    default_transform: DS.Transform;
    get default_range(): [number, number];
}
export {};
//# sourceMappingURL=ScaledAesthetic.d.ts.map