import type * as DS from '../shared';
import { Size, Jitter_speed, Jitter_radius, X, Y } from './ScaledAesthetic';
import { Filter, Foreground } from './BooleanAesthetic';
import { Color } from './ColorAesthetic';
import { Scatterplot } from '../scatterplot';
type AestheticConstructor<T> = new (...args: [
    encoding: DS.ChannelType | null,
    scatterplot: Scatterplot,
    aesthetic_map?: TextureSet,
    id?: string
]) => T;
interface IDimensions {
    [key: string]: AestheticConstructor<ConcreteAesthetic>;
}
export declare const dimensions: IDimensions;
export type ConcreteAesthetic = X | Y | Size | Jitter_speed | Jitter_radius | Color | Foreground | Filter;
export type ConcreteScaledAesthetic = X | Y | Size | Jitter_speed | Jitter_radius | Color;
import type { Dataset } from '../Dataset';
import type { Regl } from 'regl';
import type { TextureSet } from './AestheticSet';
export declare class StatefulAesthetic<T extends ConcreteAesthetic> {
    /**
     * A stateful aesthetic holds the history and associated resources for an encoding
     * channel. It holds two Aesthetic objects: the current and the previous scales. These
     * are used for things like smoothly generating interpolated paths between a previous color and a new one.
     *
     * While Aesthetics can be created and destroyed willfully, the stateful aesthetic also holds
     * a number of memory resources that it is important not to re-allocate willy-nilly. Each encoding
     * channel in a scatterplot has exactly on StatefulAesthetic that persists for the lifetime of the Plot.
     */
    states: [T, T];
    dataset: Dataset;
    regl: Regl;
    scatterplot: Scatterplot;
    needs_transitions: boolean;
    aesthetic_map: TextureSet;
    texture_buffers: any;
    ids: [string, string];
    private factory;
    constructor(scatterplot: Scatterplot, regl: Regl, dataset: Dataset, aesthetic_map: TextureSet, Factory: DS.Newable<T>);
    get current(): T;
    get last(): T;
    update(encoding: DS.ChannelType): void;
}
export {};
//# sourceMappingURL=StatefulAesthetic.d.ts.map