import { Vector, RecordBatch, StructRowProxy, Schema } from 'apache-arrow';
import type { Dataset } from './Dataset';
type MinMax = [number, number];
export type Rectangle = {
    x: MinMax;
    y: MinMax;
};
import type { TileBufferManager } from './regl_rendering';
import type { ArrowBuildable, TileManifest } from './shared';
export type RecordBatchCache = {
    batch: Promise<RecordBatch>;
    ready: false;
} | {
    batch: Promise<RecordBatch>;
    schema: Schema;
    ready: true;
};
/**
 * A Tile is, essentially, code to create an Arrow RecordBatch
 * and to associate metadata with it, in the context of a larger dataset.
 *
 */
export declare class Tile {
    readonly key: string;
    protected _batch?: RecordBatch;
    parent: Tile | null;
    private _children;
    _highest_known_ix?: number;
    dataset: Dataset;
    _transformations: Record<string, Promise<ArrowBuildable>>;
    _downloadPrimaryData?: Promise<TileManifest>;
    private partialManifest;
    private manifest?;
    private arrowFetchCalls;
    numeric_id: number;
    _buffer_manager?: TileBufferManager;
    url: string;
    constructor(key: string | Partial<TileManifest>, parent: Tile | null, dataset: Dataset, base_url: string);
    delete_column_if_exists(colname: string): void;
    get_column(colname: string): Promise<Vector>;
    private _registerChildren;
    private transformation_holder;
    apply_transformation(name: string): Promise<void>;
    add_column(name: string, data: Float32Array): RecordBatch<any>;
    /**
     * Checks if the tile has
     *
     *
     * @param col The name of the field to check for.
     * @returns
     */
    hasLoadedColumn(col: string): boolean;
    is_visible(max_ix: number, viewport_limits: Rectangle | undefined): boolean;
    points(bounding: Rectangle | undefined, sorted?: boolean): Iterable<StructRowProxy>;
    forEach(callback: (p: StructRowProxy) => void): void;
    set highest_known_ix(val: number);
    get highest_known_ix(): number;
    get record_batch(): RecordBatch<any>;
    get max_ix(): number;
    get min_ix(): number;
    yielder(): Generator<StructRowProxy<any>, void, unknown>;
    get extent(): Rectangle;
    [Symbol.iterator](): IterableIterator<StructRowProxy>;
    download_to_depth(max_ix: number, suffix: string | null): Promise<void>;
    get_arrow(suffix: string | null): Promise<RecordBatch>;
    populateManifest(): Promise<TileManifest>;
    preprocessRootTileInfo(): Promise<void>;
    loadManifestInfoFromTileMetadata(): Promise<TileManifest>;
    /**
     * Sometimes it's useful to do operations on batches of tiles. This function
     * defines a grouping of tiles in the same general region to be operated on.
     * In general they will have about 80 elements (16 + 64), but the top level
     * has just 5. (4 + 1). Note a macro tile with the name [2/0/0] does not actually include
     * the tile [2/0/0] itself, but rather the tiles [4/0/0], [4/1/0], [4/0/1], [4/1/1], [5/0/0] etc.
     */
    get macrotile(): string;
    get macro_siblings(): Array<string>;
    get loadedChildren(): Array<Tile>;
    get theoretical_extent(): Rectangle;
}
type Point = [number, number];
export declare function p_in_rect(p: Point, rect: Rectangle | undefined): boolean;
export declare const QuadTile: typeof Tile;
export {};
//# sourceMappingURL=tile.d.ts.map